"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Core
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.AsyncTasksTracker = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
/**
 * A helper to track ongoing async tasks. Usage:
 * ```
 * await using(tracker.trackAsyncTask(), async (_r) => {
 *   await doSomethingAsync();
 * });
 * ```
 *
 * Can be used with `waitForPendingAsyncs` in test helpers to wait for all
 * async tasks to complete.
 *
 * @internal
 */
class AsyncTasksTracker {
    constructor() {
        this._asyncsInProgress = new Set();
    }
    get pendingAsyncs() { return this._asyncsInProgress; }
    trackAsyncTask() {
        const id = bentleyjs_core_1.Guid.createValue();
        this._asyncsInProgress.add(id);
        return {
            dispose: () => this._asyncsInProgress.delete(id),
        };
    }
}
exports.AsyncTasksTracker = AsyncTasksTracker;
//# sourceMappingURL=AsyncTasks.js.map