/** @packageDocumentation
 * @module Core
 */
/** @alpha */
export declare type DiagnosticsLoggerSeverity = "error" | "warning" | "info" | "debug" | "trace";
/** @alpha */
export interface DiagnosticsOptions {
    /** Measure performance */
    perf?: boolean;
    /** Severity for developer log messages */
    dev?: boolean | DiagnosticsLoggerSeverity;
    /** Severity for presentation rules' editor log messages */
    editor?: boolean | DiagnosticsLoggerSeverity;
}
/** @alpha */
export declare type DiagnosticsHandler = (logs: DiagnosticsScopeLogs[]) => void;
/** @alpha */
export interface DiagnosticsOptionsWithHandler extends DiagnosticsOptions {
    handler: DiagnosticsHandler;
}
/** @alpha */
export interface DiagnosticsLogMessage {
    severity: {
        dev?: DiagnosticsLoggerSeverity;
        editor?: DiagnosticsLoggerSeverity;
    };
    category: string;
    message: string;
    timestamp: number;
}
/** @alpha */
export interface DiagnosticsScopeLogs {
    scope: string;
    duration?: number;
    logs?: DiagnosticsLogEntry[];
}
/** @alpha */
export declare type DiagnosticsLogEntry = DiagnosticsLogMessage | DiagnosticsScopeLogs;
/** @alpha */
export declare namespace DiagnosticsLogEntry {
    function isMessage(entry: DiagnosticsLogEntry): entry is DiagnosticsLogMessage;
    function isScope(entry: DiagnosticsLogEntry): entry is DiagnosticsScopeLogs;
}
//# sourceMappingURL=Diagnostics.d.ts.map