"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Core
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RelationshipPath = exports.RelatedClassInfo = exports.PropertyInfo = exports.ClassInfo = exports.InstanceKey = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
/** @public */
var InstanceKey;
(function (InstanceKey) {
    /** Compare 2 instance keys */
    function compare(lhs, rhs) {
        const classNameCompare = lhs.className.localeCompare(rhs.className);
        if (classNameCompare !== 0)
            return classNameCompare;
        return lhs.id.localeCompare(rhs.id);
    }
    InstanceKey.compare = compare;
    /** Serialize [[InstanceKey]] to JSON */
    function toJSON(json) {
        return Object.assign(Object.assign({}, json), { id: json.id.toString() });
    }
    InstanceKey.toJSON = toJSON;
    /** Deserialize [[InstanceKey]] from JSON */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { id: bentleyjs_core_1.Id64.fromJSON(json.id) });
    }
    InstanceKey.fromJSON = fromJSON;
})(InstanceKey = exports.InstanceKey || (exports.InstanceKey = {}));
/** @public */
var ClassInfo;
(function (ClassInfo) {
    /** Serialize [[ClassInfo]] to JSON */
    function toJSON(info) {
        return Object.assign(Object.assign({}, info), { id: info.id.toString() });
    }
    ClassInfo.toJSON = toJSON;
    /** Deserialize [[ClassInfo]] from JSON */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { id: bentleyjs_core_1.Id64.fromJSON(json.id) });
    }
    ClassInfo.fromJSON = fromJSON;
})(ClassInfo = exports.ClassInfo || (exports.ClassInfo = {}));
/** @public */
var PropertyInfo;
(function (PropertyInfo) {
    /** Serialize [[PropertyInfo]] to JSON */
    function toJSON(info) {
        return Object.assign(Object.assign({}, info), { classInfo: ClassInfo.toJSON(info.classInfo) });
    }
    PropertyInfo.toJSON = toJSON;
    /** Serialize [[PropertyInfo]] to compressed JSON */
    function toCompressedJSON(propertyInfo, classesMap) {
        const _a = propertyInfo.classInfo, { id } = _a, leftOverInfo = __rest(_a, ["id"]);
        classesMap[id] = leftOverInfo;
        return Object.assign(Object.assign({}, propertyInfo), { classInfo: propertyInfo.classInfo.id });
    }
    PropertyInfo.toCompressedJSON = toCompressedJSON;
    /** Deserialize [[PropertyInfo]] from JSON */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { classInfo: ClassInfo.fromJSON(json.classInfo) });
    }
    PropertyInfo.fromJSON = fromJSON;
})(PropertyInfo = exports.PropertyInfo || (exports.PropertyInfo = {}));
/** @public */
var RelatedClassInfo;
(function (RelatedClassInfo) {
    /** Serialize [[RelatedClassInfo]] to JSON */
    function toJSON(info) {
        return Object.assign(Object.assign({}, info), { sourceClassInfo: ClassInfo.toJSON(info.sourceClassInfo), targetClassInfo: ClassInfo.toJSON(info.targetClassInfo), relationshipInfo: ClassInfo.toJSON(info.relationshipInfo) });
    }
    RelatedClassInfo.toJSON = toJSON;
    /** Serialize [[RelatedClassInfo]] to compressed JSON */
    function toCompressedJSON(classInfo, classesMap) {
        const _a = classInfo.sourceClassInfo, { id: sourceId } = _a, sourceLeftOverInfo = __rest(_a, ["id"]);
        const _b = classInfo.targetClassInfo, { id: targetId } = _b, targetLeftOverInfo = __rest(_b, ["id"]);
        const _c = classInfo.relationshipInfo, { id: relationshipId } = _c, relationshipLeftOverInfo = __rest(_c, ["id"]);
        classesMap[sourceId] = sourceLeftOverInfo;
        classesMap[targetId] = targetLeftOverInfo;
        classesMap[relationshipId] = relationshipLeftOverInfo;
        return Object.assign(Object.assign({}, classInfo), { sourceClassInfo: sourceId, targetClassInfo: targetId, relationshipInfo: relationshipId });
    }
    RelatedClassInfo.toCompressedJSON = toCompressedJSON;
    /** Deserialize [[RelatedClassInfo]] from JSON */
    function fromJSON(json) {
        var _a, _b;
        return Object.assign(Object.assign({}, json), { sourceClassInfo: ClassInfo.fromJSON(json.sourceClassInfo), targetClassInfo: ClassInfo.fromJSON(json.targetClassInfo), isPolymorphicTargetClass: (_a = json.isPolymorphicTargetClass) !== null && _a !== void 0 ? _a : false, relationshipInfo: ClassInfo.fromJSON(json.relationshipInfo), isPolymorphicRelationship: (_b = json.isPolymorphicRelationship) !== null && _b !== void 0 ? _b : false });
    }
    RelatedClassInfo.fromJSON = fromJSON;
    /** Deserialize [[RelatedClassInfo]] from compressed JSON */
    function fromCompressedJSON(compressedInfoJSON, classesMap) {
        bentleyjs_core_1.assert(classesMap.hasOwnProperty(compressedInfoJSON.sourceClassInfo));
        bentleyjs_core_1.assert(classesMap.hasOwnProperty(compressedInfoJSON.targetClassInfo));
        bentleyjs_core_1.assert(classesMap.hasOwnProperty(compressedInfoJSON.relationshipInfo));
        return Object.assign(Object.assign({}, compressedInfoJSON), { sourceClassInfo: Object.assign({ id: compressedInfoJSON.sourceClassInfo }, classesMap[compressedInfoJSON.sourceClassInfo]), targetClassInfo: Object.assign({ id: compressedInfoJSON.targetClassInfo }, classesMap[compressedInfoJSON.targetClassInfo]), relationshipInfo: Object.assign({ id: compressedInfoJSON.relationshipInfo }, classesMap[compressedInfoJSON.relationshipInfo]) });
    }
    RelatedClassInfo.fromCompressedJSON = fromCompressedJSON;
    /** Check two [[RelatedClassInfo]] or [[StrippedRelatedClassInfo]] for equality */
    function equals(lhs, rhs) {
        return lhs.isForwardRelationship === rhs.isForwardRelationship
            && getClassName(lhs, "source") === getClassName(rhs, "source")
            && getClassName(lhs, "target") === getClassName(rhs, "target")
            && getClassName(lhs, "relationship") === getClassName(rhs, "relationship");
    }
    RelatedClassInfo.equals = equals;
    function isStripped(info) {
        const maybeStripped = info;
        return !!maybeStripped.relationshipName && !!maybeStripped.sourceClassName && !!maybeStripped.targetClassName;
    }
    function getClassName(info, whichClass) {
        switch (whichClass) {
            case "source": return isStripped(info) ? info.sourceClassName : info.sourceClassInfo.name;
            case "target": return isStripped(info) ? info.targetClassName : info.targetClassInfo.name;
            case "relationship": return isStripped(info) ? info.relationshipName : info.relationshipInfo.name;
        }
    }
    /** Strip given [[RelatedClassInfo]] to [[StrippedRelatedClassInfo]] */
    function strip(full) {
        return {
            sourceClassName: full.sourceClassInfo.name,
            targetClassName: full.targetClassInfo.name,
            relationshipName: full.relationshipInfo.name,
            isForwardRelationship: full.isForwardRelationship,
        };
    }
    RelatedClassInfo.strip = strip;
})(RelatedClassInfo = exports.RelatedClassInfo || (exports.RelatedClassInfo = {}));
/** @public */
var RelationshipPath;
(function (RelationshipPath) {
    /** Reverse direction of the given [[RelationshipPath]] */
    function reverse(path) {
        return [...path].reverse().map((step) => (Object.assign(Object.assign({}, step), { sourceClassInfo: step.targetClassInfo, targetClassInfo: step.sourceClassInfo, isForwardRelationship: !step.isForwardRelationship })));
    }
    RelationshipPath.reverse = reverse;
    /** Check two [[RelationshipPath]] or [[StrippedRelationshipPath]] for equality */
    function equals(lhs, rhs) {
        return lhs.length === rhs.length
            && lhs.every((lhsPart, i) => RelatedClassInfo.equals(lhsPart, rhs[i]));
    }
    RelationshipPath.equals = equals;
    /** Strip given [[RelationshipPath]] to [[StrippedRelationshipPath]] */
    function strip(full) {
        return full.map(RelatedClassInfo.strip);
    }
    RelationshipPath.strip = strip;
})(RelationshipPath = exports.RelationshipPath || (exports.RelationshipPath = {}));
//# sourceMappingURL=EC.js.map