/** @packageDocumentation
 * @module Core
 */
import { BentleyError, GetMetaDataFunction, LogFunction } from "@bentley/bentleyjs-core";
/**
 * Status codes used by Presentation APIs.
 * @public
 */
export declare enum PresentationStatus {
    /** Success result. */
    Success = 0,
    /** Request was cancelled. */
    Canceled = 1,
    /** Error: Unknown */
    Error = 65536,
    /** Error: Backend is not initialized. */
    NotInitialized = 65537,
    /**
     * Error: Attempting to use something after disposal.
     * @deprecated The value is not used anymore.
     */
    UseAfterDisposal = 65538,
    /** Error: Argument is invalid. */
    InvalidArgument = 65539,
    /**
     * Error: Received invalid response.
     * @deprecated The value is not used anymore.
     */
    InvalidResponse = 65540,
    /**
     * Error: Requested content when there is none.
     * @deprecated The value is not used anymore.
     */
    NoContent = 65541,
    /**
     * Error: Backend needs to be synced with client state.
     * @deprecated The value is not used anymore.
     */
    BackendOutOfSync = 65542,
    /**
     * Timeout for the request was reached which prevented it from being fulfilled. Frontend may
     * repeat the request.
     */
    BackendTimeout = 65543
}
/**
 * An error type thrown by Presentation APIs.
 * @public
 */
export declare class PresentationError extends BentleyError {
    /**
     * Creates an instance of Error.
     * @param errorNumber Error code
     * @param message Optional brief description of the error. The `message` property combined with the `name`
     * property is used by the `Error.prototype.toString()` method to create a string representation of the Error.
     * @param log Optional log function which logs the error.
     * @param getMetaData Optional function that returns meta-data related to an error.
     */
    constructor(errorNumber: PresentationStatus, message?: string, log?: LogFunction, getMetaData?: GetMetaDataFunction);
    /**
     * Returns the name of each error status. The name is used by the `Error.prototype.toString()`
     * method to create a string representation of the error.
     */
    protected _initName(): string;
}
//# sourceMappingURL=Error.d.ts.map