"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Core
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PresentationError = exports.PresentationStatus = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
/**
 * Status codes used by Presentation APIs.
 * @public
 */
var PresentationStatus;
(function (PresentationStatus) {
    /** Success result. */
    PresentationStatus[PresentationStatus["Success"] = 0] = "Success";
    /** Request was cancelled. */
    PresentationStatus[PresentationStatus["Canceled"] = 1] = "Canceled";
    /** Error: Unknown */
    PresentationStatus[PresentationStatus["Error"] = 65536] = "Error";
    /** Error: Backend is not initialized. */
    PresentationStatus[PresentationStatus["NotInitialized"] = 65537] = "NotInitialized";
    /**
     * Error: Attempting to use something after disposal.
     * @deprecated The value is not used anymore.
     */
    PresentationStatus[PresentationStatus["UseAfterDisposal"] = 65538] = "UseAfterDisposal";
    /** Error: Argument is invalid. */
    PresentationStatus[PresentationStatus["InvalidArgument"] = 65539] = "InvalidArgument";
    /**
     * Error: Received invalid response.
     * @deprecated The value is not used anymore.
     */
    PresentationStatus[PresentationStatus["InvalidResponse"] = 65540] = "InvalidResponse";
    /**
     * Error: Requested content when there is none.
     * @deprecated The value is not used anymore.
     */
    PresentationStatus[PresentationStatus["NoContent"] = 65541] = "NoContent";
    /**
     * Error: Backend needs to be synced with client state.
     * @deprecated The value is not used anymore.
     */
    PresentationStatus[PresentationStatus["BackendOutOfSync"] = 65542] = "BackendOutOfSync";
    /**
     * Timeout for the request was reached which prevented it from being fulfilled. Frontend may
     * repeat the request.
     */
    PresentationStatus[PresentationStatus["BackendTimeout"] = 65543] = "BackendTimeout";
})(PresentationStatus = exports.PresentationStatus || (exports.PresentationStatus = {}));
/**
 * An error type thrown by Presentation APIs.
 * @public
 */
class PresentationError extends bentleyjs_core_1.BentleyError {
    /**
     * Creates an instance of Error.
     * @param errorNumber Error code
     * @param message Optional brief description of the error. The `message` property combined with the `name`
     * property is used by the `Error.prototype.toString()` method to create a string representation of the Error.
     * @param log Optional log function which logs the error.
     * @param getMetaData Optional function that returns meta-data related to an error.
     */
    constructor(errorNumber, message, log, getMetaData) {
        super(errorNumber, message, log, "Presentation", getMetaData);
    }
    /**
     * Returns the name of each error status. The name is used by the `Error.prototype.toString()`
     * method to create a string representation of the error.
     */
    // eslint-disable-next-line @typescript-eslint/naming-convention
    _initName() {
        let value = PresentationStatus[this.errorNumber];
        if (!value)
            value = `Unknown Error (${this.errorNumber})`;
        return value;
    }
}
exports.PresentationError = PresentationError;
//# sourceMappingURL=Error.js.map