/** @packageDocumentation
 * @module Hierarchies
 */
/**
 * Data structure that describes raw composite label value.
 * @public
 */
export interface LabelCompositeValue {
    separator: string;
    values: LabelDefinition[];
}
/**
 * JSON representation of [[LabelCompositeValue]]
 * @public
 */
export interface LabelCompositeValueJSON {
    separator: string;
    values: LabelDefinitionJSON[];
}
/** @public */
export declare namespace LabelCompositeValue {
    /** Serialize given [[LabelCompositeValue]] to JSON */
    function toJSON(compositeValue: LabelCompositeValue): LabelCompositeValueJSON;
    /** Deserialize [[LabelCompositeValue]] from JSON */
    function fromJSON(json: LabelCompositeValueJSON): LabelCompositeValue;
}
/**
 * Type definition of label raw value.
 * @public
 */
export declare type LabelRawValue = string | number | boolean | LabelCompositeValue;
/**
 * JSON representation of  [[LabelRawValue]]
 * @public
 */
export declare type LabelRawValueJSON = string | number | boolean | LabelCompositeValueJSON;
/**
 * Data structure that describes label definition.
 * @public
 */
export interface LabelDefinition {
    /** Display value of label */
    displayValue: string;
    /** Raw value of label */
    rawValue: LabelRawValue;
    /** Type name of raw value */
    typeName: string;
}
/**
 * JSON representation of [[LabelDefinition]]
 * @public
 */
export interface LabelDefinitionJSON {
    displayValue: string;
    rawValue: LabelRawValueJSON;
    typeName: string;
}
/** @public */
export declare namespace LabelDefinition {
    /** Serialize given [[LabelDefinition]] to JSON */
    function toJSON(labelDefinition: LabelDefinition): LabelDefinitionJSON;
    /** Deserialize [[LabelDefinition]] from JSON */
    function fromJSON(json: LabelDefinitionJSON | string): LabelDefinition;
    /** @internal */
    const COMPOSITE_DEFINITION_TYPENAME = "composite";
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing [[LabelDefinition]] objects.
     *
     * @internal
     */
    function reviver(key: string, value: any): any;
    /** @internal */
    function isCompositeDefinition(def: LabelDefinition): def is LabelDefinition & {
        rawValue: LabelCompositeValue;
    };
    /** @internal */
    function fromLabelString(label: string): LabelDefinitionJSON;
}
//# sourceMappingURL=LabelDefinition.d.ts.map