"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hierarchies
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LabelDefinition = exports.LabelCompositeValue = void 0;
/** @public */
var LabelCompositeValue;
(function (LabelCompositeValue) {
    /** Serialize given [[LabelCompositeValue]] to JSON */
    function toJSON(compositeValue) {
        return Object.assign(Object.assign({}, compositeValue), { values: compositeValue.values.map(LabelDefinition.toJSON) });
    }
    LabelCompositeValue.toJSON = toJSON;
    /** Deserialize [[LabelCompositeValue]] from JSON */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { values: json.values.map(LabelDefinition.fromJSON) });
    }
    LabelCompositeValue.fromJSON = fromJSON;
})(LabelCompositeValue = exports.LabelCompositeValue || (exports.LabelCompositeValue = {}));
/** @public */
var LabelDefinition;
(function (LabelDefinition) {
    /** Serialize given [[LabelDefinition]] to JSON */
    function toJSON(labelDefinition) {
        return {
            displayValue: labelDefinition.displayValue,
            typeName: labelDefinition.typeName,
            rawValue: isCompositeDefinition(labelDefinition) ? LabelCompositeValue.toJSON(labelDefinition.rawValue) : labelDefinition.rawValue,
        };
    }
    LabelDefinition.toJSON = toJSON;
    /** Deserialize [[LabelDefinition]] from JSON */
    function fromJSON(json) {
        if (typeof json === "string")
            return JSON.parse(json, reviver);
        return Object.assign(Object.assign({}, json), { rawValue: isCompositeDefinition(json) ? LabelCompositeValue.fromJSON(json.rawValue) : json.rawValue });
    }
    LabelDefinition.fromJSON = fromJSON;
    /** @internal */
    LabelDefinition.COMPOSITE_DEFINITION_TYPENAME = "composite";
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing [[LabelDefinition]] objects.
     *
     * @internal
     */
    function reviver(key, value) {
        return key === "" ? fromJSON(value) : value;
    }
    LabelDefinition.reviver = reviver;
    /** @internal */
    function isCompositeDefinition(def) {
        return def.typeName === LabelDefinition.COMPOSITE_DEFINITION_TYPENAME;
    }
    LabelDefinition.isCompositeDefinition = isCompositeDefinition;
    /** @internal */
    function fromLabelString(label) {
        return {
            displayValue: label,
            rawValue: label,
            typeName: "string",
        };
    }
    LabelDefinition.fromLabelString = fromLabelString;
})(LabelDefinition = exports.LabelDefinition || (exports.LabelDefinition = {}));
//# sourceMappingURL=LabelDefinition.js.map