"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Core
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.isComputeSelectionRequestOptions = exports.isDisplayLabelsRequestOptions = exports.isDisplayLabelRequestOptions = exports.isExtendedContentRequestOptions = exports.isContentDescriptorRequestOptions = exports.isExtendedHierarchyRequestOptions = exports.PresentationUnitSystem = exports.RequestPriority = void 0;
/**
 * Enumeration of standard request priorities.
 * @public
 */
var RequestPriority;
(function (RequestPriority) {
    /** Priority for pre-loading requests */
    RequestPriority[RequestPriority["Preload"] = 0] = "Preload";
    /** Priority for general requests */
    RequestPriority[RequestPriority["Normal"] = 1000] = "Normal";
    /** Max possible priority */
    RequestPriority[RequestPriority["Max"] = Number.MAX_SAFE_INTEGER] = "Max";
})(RequestPriority = exports.RequestPriority || (exports.RequestPriority = {}));
/**
 * Enumeration of unit systems that can be used when formatting values.
 * @beta
 */
var PresentationUnitSystem;
(function (PresentationUnitSystem) {
    PresentationUnitSystem["Metric"] = "metric";
    PresentationUnitSystem["BritishImperial"] = "british-imperial";
    PresentationUnitSystem["UsCustomary"] = "us-customary";
    PresentationUnitSystem["UsSurvey"] = "us-survey";
})(PresentationUnitSystem = exports.PresentationUnitSystem || (exports.PresentationUnitSystem = {}));
/** @internal */
// eslint-disable-next-line deprecation/deprecation
const isExtendedHierarchyRequestOptions = (opts) => {
    return !!opts.parentKey;
};
exports.isExtendedHierarchyRequestOptions = isExtendedHierarchyRequestOptions;
/** @internal */
// eslint-disable-next-line deprecation/deprecation
const isContentDescriptorRequestOptions = (opts) => {
    return !!opts.keys;
};
exports.isContentDescriptorRequestOptions = isContentDescriptorRequestOptions;
/** @internal */
// eslint-disable-next-line deprecation/deprecation
const isExtendedContentRequestOptions = (opts) => {
    return !!opts.descriptor
        && !!opts.keys;
};
exports.isExtendedContentRequestOptions = isExtendedContentRequestOptions;
/** @internal */
// eslint-disable-next-line deprecation/deprecation
const isDisplayLabelRequestOptions = (opts) => {
    return !!opts.key;
};
exports.isDisplayLabelRequestOptions = isDisplayLabelRequestOptions;
/** @internal */
// eslint-disable-next-line deprecation/deprecation
const isDisplayLabelsRequestOptions = (opts) => {
    return !!opts.keys;
};
exports.isDisplayLabelsRequestOptions = isDisplayLabelsRequestOptions;
/** @internal */
function isComputeSelectionRequestOptions(options) {
    return !!options.elementIds;
}
exports.isComputeSelectionRequestOptions = isComputeSelectionRequestOptions;
//# sourceMappingURL=PresentationManagerOptions.js.map