"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module RPC
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.PresentationIpcEvents = exports.PresentationRpcInterface = void 0;
const imodeljs_common_1 = require("@bentley/imodeljs-common");
/**
 * Interface used for communication between Presentation backend and frontend.
 * @public
 */
class PresentationRpcInterface extends imodeljs_common_1.RpcInterface {
    // eslint-disable-next-line deprecation/deprecation
    async getNodesCount(_token, _options, _parentKey) { return this.forward(arguments); }
    /** @deprecated Use [[getPagedNodes]] */
    // eslint-disable-next-line deprecation/deprecation
    async getNodesAndCount(_token, _options, _parentKey) { return this.forward(arguments); }
    /** @deprecated Use [[getPagedNodes]] */
    // eslint-disable-next-line deprecation/deprecation
    async getNodes(_token, _options, _parentKey) { return this.forward(arguments); }
    async getPagedNodes(_token, _options) { return this.forward(arguments); }
    // TODO: add paged version of this (#387280)
    async getNodePaths(_token, _options, _paths, _markedIndex) { return this.forward(arguments); }
    // TODO: add paged version of this (#387280)
    async getFilteredNodePaths(_token, _options, _filterText) { return this.forward(arguments); }
    /** @alpha @deprecated Will be removed in 3.0 */
    // istanbul ignore next
    // eslint-disable-next-line deprecation/deprecation
    async loadHierarchy(_token, _options) { return this.forward(arguments); }
    // eslint-disable-next-line deprecation/deprecation
    async getContentDescriptor(_token, _options, _displayType, _keys, _selection) { return this.forward(arguments); }
    // eslint-disable-next-line deprecation/deprecation
    async getContentSetSize(_token, _options, _descriptorOrOverrides, _keys) { return this.forward(arguments); }
    /** @deprecated Use [[getPagedContent]] or [[getPagedContentSet]] */
    // eslint-disable-next-line deprecation/deprecation
    async getContent(_token, _options, _descriptorOrOverrides, _keys) { return this.forward(arguments); }
    /** @deprecated Use [[getPagedContent]] or [[getPagedContentSet]] */
    // eslint-disable-next-line deprecation/deprecation
    async getContentAndSize(_token, _options, _descriptorOrOverrides, _keys) { return this.forward(arguments); }
    async getPagedContent(_token, _options) { return this.forward(arguments); }
    async getPagedContentSet(_token, _options) { return this.forward(arguments); }
    /** @beta */
    async getElementProperties(_token, _options) { return this.forward(arguments); }
    /** @deprecated Use [[getPagedDistinctValues]] */
    // eslint-disable-next-line deprecation/deprecation
    async getDistinctValues(_token, _options, _descriptor, _keys, _fieldName, _maximumValueCount) { return this.forward(arguments); }
    async getPagedDistinctValues(_token, _options) { return this.forward(arguments); }
    // eslint-disable-next-line deprecation/deprecation
    async getDisplayLabelDefinition(_token, _options, _key) { return this.forward(arguments); }
    /** @deprecated Use [[getPagedDisplayLabelDefinitions]] */
    // eslint-disable-next-line deprecation/deprecation
    async getDisplayLabelDefinitions(_token, _options, _keys) { return this.forward(arguments); }
    async getPagedDisplayLabelDefinitions(_token, _options) { return this.forward(arguments); }
    async getSelectionScopes(_token, _options) { return this.forward(arguments); }
    async computeSelection(_token, _options, _ids, _scopeId) { return this.forward(arguments); }
    /** @alpha @deprecated Use [[compareHierarchiesPaged]] */
    async compareHierarchies(_token, _options) { return this.forward(arguments); }
    async compareHierarchiesPaged(_token, _options) { return this.forward(arguments); }
}
exports.PresentationRpcInterface = PresentationRpcInterface;
/** The immutable name of the interface. */
PresentationRpcInterface.interfaceName = "PresentationRpcInterface"; // eslint-disable-line @typescript-eslint/naming-convention
/** The semantic version of the interface. */
PresentationRpcInterface.interfaceVersion = "2.11.0";
/** @alpha */
var PresentationIpcEvents;
(function (PresentationIpcEvents) {
    /**
     * ID of an event that's emitted when backend detects changes in presented data.
     */
    PresentationIpcEvents["Update"] = "presentation.onUpdate";
})(PresentationIpcEvents = exports.PresentationIpcEvents || (exports.PresentationIpcEvents = {}));
//# sourceMappingURL=PresentationRpcInterface.js.map