"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Core
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegisteredRuleset = void 0;
/**
 * A ruleset that is registered in a ruleset manager.
 * @public
 */
class RegisteredRuleset {
    /** Create a registered ruleset */
    constructor(ruleset, uniqueIdentifier, disposeFunc) {
        this._disposeFunc = disposeFunc;
        this._ruleset = ruleset;
        this._uniqueIdentifier = uniqueIdentifier;
    }
    /** Dispose registered ruleset. */
    dispose() {
        this._disposeFunc(this);
    }
    get uniqueIdentifier() { return this._uniqueIdentifier; }
    get id() { return this._ruleset.id; }
    get supportedSchemas() {
        // eslint-disable-next-line deprecation/deprecation
        return this._ruleset.supportedSchemas;
    }
    get supplementationInfo() { return this._ruleset.supplementationInfo; }
    get rules() { return this._ruleset.rules; }
    get vars() { return this._ruleset.vars; }
    toJSON() { return this._ruleset; }
}
exports.RegisteredRuleset = RegisteredRuleset;
//# sourceMappingURL=RegisteredRuleset.js.map