"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Core
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.HierarchyCompareInfo = exports.PartialHierarchyModification = exports.HierarchyUpdateInfo = exports.HierarchyUpdateRecord = exports.ExpandedNodeUpdateRecord = exports.UpdateInfo = exports.UPDATE_FULL = void 0;
const Key_1 = require("./hierarchy/Key");
const Node_1 = require("./hierarchy/Node");
/** @alpha */
exports.UPDATE_FULL = "FULL";
/** @alpha */
var UpdateInfo;
(function (UpdateInfo) {
    /** Serialize given object to JSON. */
    function toJSON(obj) {
        const json = {};
        for (const imodel in obj) {
            // istanbul ignore if
            if (!obj.hasOwnProperty(imodel))
                continue;
            json[imodel] = {};
            const rulesetObj = obj[imodel];
            for (const rulesetId in rulesetObj) {
                // istanbul ignore if
                if (!rulesetObj.hasOwnProperty(rulesetId))
                    continue;
                json[imodel][rulesetId] = {
                    hierarchy: rulesetObj[rulesetId].hierarchy ? HierarchyUpdateInfo.toJSON(rulesetObj[rulesetId].hierarchy) : undefined,
                    content: rulesetObj[rulesetId].content,
                };
            }
        }
        return json;
    }
    UpdateInfo.toJSON = toJSON;
    /** Deserialize given object from JSON */
    function fromJSON(json) {
        const obj = {};
        for (const imodel in json) {
            // istanbul ignore if
            if (!json.hasOwnProperty(imodel))
                continue;
            obj[imodel] = {};
            const rulesetJson = json[imodel];
            for (const rulesetId in rulesetJson) {
                // istanbul ignore if
                if (!rulesetJson.hasOwnProperty(rulesetId))
                    continue;
                obj[imodel][rulesetId] = {
                    hierarchy: rulesetJson[rulesetId].hierarchy ? HierarchyUpdateInfo.fromJSON(rulesetJson[rulesetId].hierarchy) : undefined,
                    content: rulesetJson[rulesetId].content,
                };
            }
        }
        return obj;
    }
    UpdateInfo.fromJSON = fromJSON;
})(UpdateInfo = exports.UpdateInfo || (exports.UpdateInfo = {}));
/** @alpha */
var ExpandedNodeUpdateRecord;
(function (ExpandedNodeUpdateRecord) {
    /** Serialize given object to JSON. */
    function toJSON(obj) {
        return Object.assign(Object.assign({}, obj), { node: Node_1.Node.toJSON(obj.node) });
    }
    ExpandedNodeUpdateRecord.toJSON = toJSON;
    /** Deserialize given object from JSON */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { node: Node_1.Node.fromJSON(json.node) });
    }
    ExpandedNodeUpdateRecord.fromJSON = fromJSON;
})(ExpandedNodeUpdateRecord = exports.ExpandedNodeUpdateRecord || (exports.ExpandedNodeUpdateRecord = {}));
/** @alpha */
var HierarchyUpdateRecord;
(function (HierarchyUpdateRecord) {
    /** Serialize given object to JSON. */
    function toJSON(obj) {
        return Object.assign(Object.assign({}, obj), { parent: obj.parent ? Key_1.NodeKey.toJSON(obj.parent) : undefined, expandedNodes: obj.expandedNodes ? obj.expandedNodes.map(ExpandedNodeUpdateRecord.toJSON) : undefined });
    }
    HierarchyUpdateRecord.toJSON = toJSON;
    /** Deserialize given object from JSON */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { parent: json.parent ? Key_1.NodeKey.fromJSON(json.parent) : undefined, expandedNodes: json.expandedNodes ? json.expandedNodes.map(ExpandedNodeUpdateRecord.fromJSON) : undefined });
    }
    HierarchyUpdateRecord.fromJSON = fromJSON;
})(HierarchyUpdateRecord = exports.HierarchyUpdateRecord || (exports.HierarchyUpdateRecord = {}));
/** @alpha */
var HierarchyUpdateInfo;
(function (HierarchyUpdateInfo) {
    /** Serialize given object to JSON. */
    function toJSON(obj) {
        if (typeof obj === "string")
            return obj;
        return obj.map(HierarchyUpdateRecord.toJSON);
    }
    HierarchyUpdateInfo.toJSON = toJSON;
    /** Deserialize given object from JSON */
    function fromJSON(json) {
        if (typeof json === "string")
            return json;
        return json.map(HierarchyUpdateRecord.fromJSON);
    }
    HierarchyUpdateInfo.fromJSON = fromJSON;
})(HierarchyUpdateInfo = exports.HierarchyUpdateInfo || (exports.HierarchyUpdateInfo = {}));
/** @public */
var PartialHierarchyModification;
(function (PartialHierarchyModification) {
    /** Serialize given object to JSON. */
    function toJSON(obj) {
        switch (obj.type) {
            case "Insert":
                return {
                    type: "Insert",
                    parent: obj.parent === undefined ? undefined : Key_1.NodeKey.toJSON(obj.parent),
                    position: obj.position,
                    node: Node_1.Node.toJSON(obj.node),
                };
            case "Update":
                return {
                    type: "Update",
                    target: Key_1.NodeKey.toJSON(obj.target),
                    changes: Node_1.Node.toPartialJSON(obj.changes),
                };
            case "Delete":
                return {
                    type: "Delete",
                    // eslint-disable-next-line deprecation/deprecation
                    target: Key_1.NodeKey.toJSON(obj.target),
                    parent: obj.parent === undefined ? undefined : Key_1.NodeKey.toJSON(obj.parent),
                    position: obj.position,
                };
        }
    }
    PartialHierarchyModification.toJSON = toJSON;
    /** Deserialize given object from JSON */
    function fromJSON(json) {
        switch (json.type) {
            case "Insert":
                return {
                    type: "Insert",
                    parent: json.parent === undefined ? undefined : Key_1.NodeKey.fromJSON(json.parent),
                    position: json.position,
                    node: Node_1.Node.fromJSON(json.node),
                };
            case "Update":
                return {
                    type: "Update",
                    target: Key_1.NodeKey.fromJSON(json.target),
                    changes: Node_1.Node.fromPartialJSON(json.changes),
                };
            case "Delete":
                return {
                    type: "Delete",
                    // eslint-disable-next-line deprecation/deprecation
                    target: Key_1.NodeKey.fromJSON(json.target),
                    parent: json.parent === undefined ? undefined : Key_1.NodeKey.fromJSON(json.parent),
                    position: json.position,
                };
        }
    }
    PartialHierarchyModification.fromJSON = fromJSON;
})(PartialHierarchyModification = exports.PartialHierarchyModification || (exports.PartialHierarchyModification = {}));
/** @public */
var HierarchyCompareInfo;
(function (HierarchyCompareInfo) {
    /** Serialize given object to JSON. */
    function toJSON(obj) {
        return Object.assign(Object.assign({}, obj), { changes: obj.changes.map((change) => PartialHierarchyModification.toJSON(change)) });
    }
    HierarchyCompareInfo.toJSON = toJSON;
    /** Deserialize given object from JSON */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { changes: json.changes.map((change) => PartialHierarchyModification.fromJSON(change)) });
    }
    HierarchyCompareInfo.fromJSON = fromJSON;
})(HierarchyCompareInfo = exports.HierarchyCompareInfo || (exports.HierarchyCompareInfo = {}));
//# sourceMappingURL=Update.js.map