"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Core
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLocalesDirectory = exports.PRESENTATION_COMMON_ROOT = exports.DEFAULT_KEYS_BATCH_SIZE = exports.getInstancesCount = void 0;
const path = __importStar(require("path"));
const Key_1 = require("./hierarchy/Key");
/**
 * Get total number of instances included in the supplied key set. The
 * count is calculated by adding all of the following:
 * - `keys.instanceKeysCount`
 * - number of `keys.nodeKeys` which are *ECInstance* keys
 * - for every grouping node key in `keys.nodeKeys`, number of grouped instances
 *
 * E.g. if `keys` contains one instance key, one *ECInstance* node key
 * and one grouping node key which groups 3 instances, the result is 5.
 *
 * @public
 */
const getInstancesCount = (keys) => {
    let count = keys.instanceKeysCount;
    keys.nodeKeys.forEach((key) => {
        if (Key_1.NodeKey.isInstancesNodeKey(key)) {
            count += key.instanceKeys.length;
        }
        else if (Key_1.NodeKey.isGroupingNodeKey(key)) {
            count += key.groupedInstancesCount;
        }
    });
    return count;
};
exports.getInstancesCount = getInstancesCount;
/**
 * Default (recommended) keyset batch size for cases when it needs to be sent
 * over HTTP. Sending keys in batches helps avoid HTTP413 error.
 *
 * @public
 */
exports.DEFAULT_KEYS_BATCH_SIZE = 5000;
/** @internal */
exports.PRESENTATION_COMMON_ROOT = __dirname;
/** @internal */
// istanbul ignore next
const getLocalesDirectory = (assetsDirectory) => path.join(assetsDirectory, "locales");
exports.getLocalesDirectory = getLocalesDirectory;
//# sourceMappingURL=Utils.js.map