"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Content
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.CategoryDescription = void 0;
/** @public */
var CategoryDescription;
(function (CategoryDescription) {
    /** Serialize given category to JSON */
    function toJSON(category) {
        var _a;
        return Object.assign(Object.assign({}, category), { parent: (_a = category.parent) === null || _a === void 0 ? void 0 : _a.name });
    }
    CategoryDescription.toJSON = toJSON;
    /**
     * Deserialize [[CategoryDescription]] from JSON. The `parent` is not assigned - use listFromJSON
     * to deserialize the whole categories list and set parents.
     */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { parent: undefined });
    }
    CategoryDescription.fromJSON = fromJSON;
    function createCategoriesHierarchy(json, categoriesMap) {
        const category = categoriesMap.get(json.name);
        if (json.parent) {
            // note: mutating categories in the `categoriesMap`
            category.parent = categoriesMap.get(json.parent);
        }
        return category;
    }
    /** Deserialize a list of [[CategoryDescription]] from JSON. */
    function listFromJSON(json) {
        const categoriesMap = new Map();
        json.forEach((categoryJson) => categoriesMap.set(categoryJson.name, Object.assign(Object.assign({}, categoryJson), { parent: undefined })));
        return json.map((categoryJson) => createCategoriesHierarchy(categoryJson, categoriesMap));
    }
    CategoryDescription.listFromJSON = listFromJSON;
})(CategoryDescription = exports.CategoryDescription || (exports.CategoryDescription = {}));
//# sourceMappingURL=Category.js.map