/** @packageDocumentation
 * @module Content
 */
import { Descriptor, DescriptorJSON } from "./Descriptor";
import { Item, ItemJSON } from "./Item";
/**
 * Serialized [[Content]] JSON representation.
 * @public
 */
export interface ContentJSON {
    descriptor: DescriptorJSON;
    contentSet: ItemJSON[];
}
/**
 * A data structure that contains the [[Descriptor]] and a list of [[Item]]
 * objects which are based on that descriptor.
 *
 * @public
 */
export declare class Content {
    /** Descriptor used to create the content */
    readonly descriptor: Descriptor;
    /** Content items */
    readonly contentSet: Item[];
    /** Create a new [[Content]] instance */
    constructor(descriptor: Descriptor, items: Item[]);
    /** Serialize this object to JSON */
    toJSON(): ContentJSON;
    /** Deserialize [[Content]] from JSON */
    static fromJSON(json: ContentJSON | string | undefined): Content | undefined;
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing Content objects.
     *
     * @internal
     */
    static reviver(key: string, value: any): any;
}
//# sourceMappingURL=Content.d.ts.map