"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Content
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Content = void 0;
const Descriptor_1 = require("./Descriptor");
const Item_1 = require("./Item");
/**
 * A data structure that contains the [[Descriptor]] and a list of [[Item]]
 * objects which are based on that descriptor.
 *
 * @public
 */
class Content {
    /** Create a new [[Content]] instance */
    constructor(descriptor, items) {
        this.descriptor = descriptor;
        this.contentSet = items;
    }
    /** Serialize this object to JSON */
    toJSON() {
        return {
            descriptor: this.descriptor.toJSON(),
            contentSet: this.contentSet.map((item) => item.toJSON()),
        };
    }
    /** Deserialize [[Content]] from JSON */
    static fromJSON(json) {
        if (!json)
            return undefined;
        if (typeof json === "string")
            return JSON.parse(json, Content.reviver);
        const descriptor = Descriptor_1.Descriptor.fromJSON(json.descriptor);
        if (!descriptor)
            return undefined;
        const contentSet = json.contentSet
            .map((itemJson) => Item_1.Item.fromJSON(itemJson))
            .filter((item) => (item !== undefined));
        return new Content(descriptor, contentSet);
    }
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing Content objects.
     *
     * @internal
     */
    static reviver(key, value) {
        return key === "" ? Content.fromJSON(value) : value;
    }
}
exports.Content = Content;
//# sourceMappingURL=Content.js.map