"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Content
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Descriptor = exports.SortDirection = exports.ContentFlags = exports.SelectClassInfo = void 0;
const bentleyjs_core_1 = require("@bentley/bentleyjs-core");
const EC_1 = require("../EC");
const Category_1 = require("./Category");
const Fields_1 = require("./Fields");
/** @public */
var SelectClassInfo;
(function (SelectClassInfo) {
    /** Deserialize [[SelectClassInfo]] from JSON */
    function fromJSON(json) {
        return Object.assign(Object.assign({}, json), { selectClassInfo: EC_1.ClassInfo.fromJSON(json.selectClassInfo), pathToPrimaryClass: json.pathToPrimaryClass.map((p) => EC_1.RelatedClassInfo.fromJSON(p)), relatedPropertyPaths: json.relatedPropertyPaths.map((rp) => (rp.map((p) => EC_1.RelatedClassInfo.fromJSON(p)))), navigationPropertyClasses: json.navigationPropertyClasses.map((p) => EC_1.RelatedClassInfo.fromJSON(p)), relatedInstanceClasses: json.relatedInstanceClasses.map((p) => EC_1.RelatedClassInfo.fromJSON(p)) });
    }
    SelectClassInfo.fromJSON = fromJSON;
    /** Deserialize [[SelectClassInfo]] from compressed JSON */
    function fromCompressedJSON(compressedSelectClass, classesMap) {
        bentleyjs_core_1.assert(classesMap.hasOwnProperty(compressedSelectClass.selectClassInfo));
        return Object.assign(Object.assign({}, compressedSelectClass), { selectClassInfo: Object.assign({ id: compressedSelectClass.selectClassInfo }, classesMap[compressedSelectClass.selectClassInfo]), navigationPropertyClasses: compressedSelectClass.navigationPropertyClasses.map((compressedInfoJSON) => EC_1.RelatedClassInfo.fromCompressedJSON(compressedInfoJSON, classesMap)), relatedInstanceClasses: compressedSelectClass.relatedInstanceClasses.map((compressedInfoJSON) => EC_1.RelatedClassInfo.fromCompressedJSON(compressedInfoJSON, classesMap)), pathToPrimaryClass: compressedSelectClass.pathToPrimaryClass.map((compressedInfoJSON) => EC_1.RelatedClassInfo.fromCompressedJSON(compressedInfoJSON, classesMap)), relatedPropertyPaths: compressedSelectClass.relatedPropertyPaths.map((path) => path.map((compressedInfoJSON) => EC_1.RelatedClassInfo.fromCompressedJSON(compressedInfoJSON, classesMap))) });
    }
    SelectClassInfo.fromCompressedJSON = fromCompressedJSON;
    /** Serialize [[SelectClassInfo]] to compressed JSON */
    function toCompressedJSON(selectClass, classesMap) {
        const _a = selectClass.selectClassInfo, { id } = _a, leftOverInfo = __rest(_a, ["id"]);
        classesMap[id] = leftOverInfo;
        return Object.assign(Object.assign({}, selectClass), { selectClassInfo: id, relatedInstanceClasses: selectClass.relatedInstanceClasses.map((instanceClass) => EC_1.RelatedClassInfo.toCompressedJSON(instanceClass, classesMap)), navigationPropertyClasses: selectClass.navigationPropertyClasses.map((propertyClass) => EC_1.RelatedClassInfo.toCompressedJSON(propertyClass, classesMap)), pathToPrimaryClass: selectClass.pathToPrimaryClass.map((relatedClass) => EC_1.RelatedClassInfo.toCompressedJSON(relatedClass, classesMap)), relatedPropertyPaths: selectClass.relatedPropertyPaths.map((path) => path.map((relatedClass) => EC_1.RelatedClassInfo.toCompressedJSON(relatedClass, classesMap))) });
    }
    SelectClassInfo.toCompressedJSON = toCompressedJSON;
})(SelectClassInfo = exports.SelectClassInfo || (exports.SelectClassInfo = {}));
/**
 * Flags that control content format.
 * @public
 */
var ContentFlags;
(function (ContentFlags) {
    /** Each content record only has [[InstanceKey]] and no data */
    ContentFlags[ContentFlags["KeysOnly"] = 1] = "KeysOnly";
    /** Each content record additionally has an image id */
    ContentFlags[ContentFlags["ShowImages"] = 2] = "ShowImages";
    /** Each content record additionally has a display label */
    ContentFlags[ContentFlags["ShowLabels"] = 4] = "ShowLabels";
    /** All content records are merged into a single record (see [Merging values]($docs/learning/presentation/content/terminology#value-merging)) */
    ContentFlags[ContentFlags["MergeResults"] = 8] = "MergeResults";
    /** Content has only distinct values */
    ContentFlags[ContentFlags["DistinctValues"] = 16] = "DistinctValues";
    /** Doesn't create property or calculated fields. Can be used in conjunction with [[ShowLabels]]. */
    ContentFlags[ContentFlags["NoFields"] = 32] = "NoFields";
    /**
     * Set related input keys on [[Item]] objects when creating content. This helps identify which [[Item]] is associated to which
     * given input key at the cost of performance creating those items.
     *
     * @beta
     */
    ContentFlags[ContentFlags["IncludeInputKeys"] = 256] = "IncludeInputKeys";
})(ContentFlags = exports.ContentFlags || (exports.ContentFlags = {}));
/**
 * Data sorting direction
 * @public
 */
var SortDirection;
(function (SortDirection) {
    SortDirection[SortDirection["Ascending"] = 0] = "Ascending";
    SortDirection[SortDirection["Descending"] = 1] = "Descending";
})(SortDirection = exports.SortDirection || (exports.SortDirection = {}));
function isCompressedDescriptorJSON(descriptorJSON) {
    return descriptorJSON.classesMap !== undefined;
}
/**
 * Data structure that describes content: fields, sorting, filtering, format, etc.
 * Descriptor may be changed to control how content is created.
 *
 * @public
 */
class Descriptor {
    /** Construct a new Descriptor using a `DescriptorSource` */
    constructor(source) {
        var _a;
        const fields = [...source.fields];
        Object.assign(this, source, {
            selectClasses: [...source.selectClasses],
            categories: [...((_a = source.categories) !== null && _a !== void 0 ? _a : Descriptor.getCategoriesFromFields(fields))],
            fields,
        });
    }
    /** Serialize this object to JSON */
    toJSON() {
        return Object.assign(Object.assign({}, this), { categories: this.categories.map(Category_1.CategoryDescription.toJSON), fields: this.fields.map((field) => field.toJSON()) });
    }
    /** Serialize [[Descriptor]] to compressed JSON */
    toCompressedJSON() {
        const classesMap = {};
        const selectClasses = this.selectClasses.map((selectClass) => SelectClassInfo.toCompressedJSON(selectClass, classesMap));
        const fields = this.fields.map((field) => field.toCompressedJSON(classesMap));
        return Object.assign({}, this.sortingField !== undefined && { sortingFieldName: this.sortingField.name }, this.sortDirection !== undefined && { sortDirection: this.sortDirection }, this.filterExpression !== undefined && { filterExpression: this.filterExpression }, this.selectionInfo !== undefined && { selectionInfo: this.selectionInfo }, {
            connectionId: this.connectionId,
            inputKeysHash: this.inputKeysHash,
            contentOptions: this.contentOptions,
            displayType: this.displayType,
            contentFlags: this.contentFlags,
            categories: this.categories.map(Category_1.CategoryDescription.toJSON),
            fields,
            selectClasses,
            classesMap,
        });
    }
    /** Deserialize [[Descriptor]] from JSON */
    static fromJSON(json) {
        if (!json)
            return undefined;
        if (typeof json === "string")
            return JSON.parse(json, Descriptor.reviver);
        if (isCompressedDescriptorJSON(json))
            json = Descriptor.fromCompressedJSON(json);
        return json.categories
            ? this.fromJSONWithCategories(json)
            : this.fromJSONWithoutCategories(json);
    }
    static fromJSONWithCategories(json) {
        const descriptor = Object.create(Descriptor.prototype);
        const categories = Category_1.CategoryDescription.listFromJSON(json.categories);
        const fields = this.getFieldsFromJSON(json.fields, (fieldJson) => Fields_1.Field.fromJSON(fieldJson, categories));
        const sortingField = json.sortingFieldName ? Fields_1.getFieldByName(fields, json.sortingFieldName, true) : undefined;
        return Object.assign(descriptor, json, {
            selectClasses: json.selectClasses.map(SelectClassInfo.fromJSON),
            categories,
            fields,
            sortingField,
        });
    }
    static fromJSONWithoutCategories(json) {
        const descriptor = Object.create(Descriptor.prototype);
        const fields = this.getFieldsFromJSON(json.fields, /* eslint-disable-line deprecation/deprecation */ Fields_1.Field.fromJSON);
        const sortingField = json.sortingFieldName ? Fields_1.getFieldByName(fields, json.sortingFieldName, true) : undefined;
        return Object.assign(descriptor, json, {
            selectClasses: json.selectClasses.map(SelectClassInfo.fromJSON),
            categories: this.getCategoriesFromFields(fields),
            fields,
            sortingField,
        });
    }
    static fromCompressedJSON(json) {
        const { classesMap } = json, leftOverJson = __rest(json, ["classesMap"]);
        const decompressedSelectClasses = json.selectClasses.map((compressedSelectClass) => SelectClassInfo.fromCompressedJSON(compressedSelectClass, classesMap));
        const decompressedFieldJSON = json.fields.map((compressedFieldJSON) => Fields_1.Field.fromCompressedJSON(compressedFieldJSON, classesMap)).filter((decompressedJson) => !!decompressedJson);
        const descriptorJSON = Object.assign(Object.assign({}, leftOverJson), { selectClasses: decompressedSelectClasses, fields: decompressedFieldJSON });
        return descriptorJSON;
    }
    static getFieldsFromJSON(json, factory) {
        return json.map((fieldJson) => {
            const field = factory(fieldJson);
            if (field)
                field.rebuildParentship();
            return field;
        }).filter((field) => !!field);
    }
    static getCategoriesFromFields(fields) {
        const categories = new Map();
        const forEachField = (fieldsInternal, cb) => {
            fieldsInternal.forEach((field) => {
                cb(field);
                if (field.isNestedContentField())
                    forEachField(field.nestedFields, cb);
            });
        };
        forEachField(fields, (field) => {
            const name = field.category.name;
            const existingCategory = categories.get(name);
            if (existingCategory)
                field.category = existingCategory;
            else
                categories.set(name, field.category);
        });
        return [...categories.values()];
    }
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing Content objects.
     *
     * @internal
     */
    static reviver(key, value) {
        return key === "" ? Descriptor.fromJSON(value) : value;
    }
    /**
     * Get field by its name
     * @param name Name of the field to find
     * @param recurse Recurse into nested fields
     */
    getFieldByName(name, recurse) {
        return Fields_1.getFieldByName(this.fields, name, recurse);
    }
    /**
     * Create descriptor overrides object from this descriptor.
     * @public
     */
    createDescriptorOverrides() {
        var _a;
        const overrides = {};
        if (this.displayType)
            overrides.displayType = this.displayType;
        if (this.contentFlags !== 0)
            overrides.contentFlags = this.contentFlags;
        if (this.filterExpression)
            overrides.filterExpression = this.filterExpression;
        if (this.sortingField)
            overrides.sorting = { field: this.sortingField.getFieldDescriptor(), direction: (_a = this.sortDirection) !== null && _a !== void 0 ? _a : SortDirection.Ascending };
        return overrides;
    }
}
exports.Descriptor = Descriptor;
//# sourceMappingURL=Descriptor.js.map