"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Content
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Item = void 0;
const EC_1 = require("../EC");
const LabelDefinition_1 = require("../LabelDefinition");
const Value_1 = require("./Value");
/**
 * A data structure that represents a single content record.
 * @public
 */
class Item {
    /**
     * Creates an instance of Item.
     * @param primaryKeys Keys of instances whose data is contained in this item
     * @param label Display label of the item
     * @param imageId ID of the image associated with this item
     * @param classInfo For cases when item consists only of same class instances, information about the ECClass
     * @param values Raw values dictionary
     * @param displayValues Display values dictionary
     * @param mergedFieldNames List of field names whose values are merged (see [Merging values]($docs/learning/presentation/Content/Terminology#value-merging))
     * @param extendedData Extended data injected into this content item
     */
    constructor(primaryKeys, label, imageId, classInfo, values, displayValues, mergedFieldNames, extendedData) {
        this.primaryKeys = primaryKeys;
        this.imageId = imageId;
        this.classInfo = classInfo;
        this.values = values;
        this.displayValues = displayValues;
        this.mergedFieldNames = mergedFieldNames;
        this.extendedData = extendedData;
        this.label = (typeof label === "string") ? LabelDefinition_1.LabelDefinition.fromLabelString(label) : label;
    }
    /**
     * Is value of field with the specified name merged in this record.
     */
    isFieldMerged(fieldName) {
        return -1 !== this.mergedFieldNames.indexOf(fieldName);
    }
    /** Serialize this object to JSON */
    toJSON() {
        const _a = this, { label } = _a, baseItem = __rest(_a, ["label"]);
        return Object.assign(Object.assign(Object.assign({}, baseItem), (this.inputKeys ? { inputKeys: this.inputKeys.map(EC_1.InstanceKey.toJSON) } : {})), { primaryKeys: this.primaryKeys.map(EC_1.InstanceKey.toJSON), classInfo: this.classInfo ? EC_1.ClassInfo.toJSON(this.classInfo) : undefined, values: Value_1.Value.toJSON(this.values), displayValues: Value_1.DisplayValue.toJSON(this.displayValues), labelDefinition: LabelDefinition_1.LabelDefinition.toJSON(label) });
    }
    /** Deserialize [[Item]] from JSON */
    static fromJSON(json) {
        if (!json)
            return undefined;
        if (typeof json === "string")
            return JSON.parse(json, Item.reviver);
        const item = Object.create(Item.prototype);
        const { labelDefinition } = json, baseJson = __rest(json, ["labelDefinition"]);
        return Object.assign(item, baseJson, Object.assign(Object.assign({}, (json.inputKeys ? { inputKeys: json.inputKeys.map((ik) => EC_1.InstanceKey.fromJSON(ik)) } : {})), { primaryKeys: json.primaryKeys.map((pk) => EC_1.InstanceKey.fromJSON(pk)), classInfo: json.classInfo ? EC_1.ClassInfo.fromJSON(json.classInfo) : undefined, values: Value_1.Value.fromJSON(json.values), displayValues: Value_1.DisplayValue.fromJSON(json.displayValues), label: LabelDefinition_1.LabelDefinition.fromJSON(labelDefinition) }));
    }
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing Item objects.
     *
     * @internal
     */
    static reviver(key, value) {
        return key === "" ? Item.fromJSON(value) : value;
    }
}
exports.Item = Item;
//# sourceMappingURL=Item.js.map