"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Content
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Property = void 0;
const EC_1 = require("../EC");
/** @public */
var Property;
(function (Property) {
    /** Serialize [[Property]] to JSON */
    function toJSON(prop) {
        return {
            property: EC_1.PropertyInfo.toJSON(prop.property),
            // eslint-disable-next-line deprecation/deprecation
            relatedClassPath: prop.relatedClassPath.map((classInfo) => EC_1.RelatedClassInfo.toJSON(classInfo)),
        };
    }
    Property.toJSON = toJSON;
    /** Serialize [[Property]] to compressed JSON */
    function toCompressedJSON(prop, classesMap) {
        return {
            property: EC_1.PropertyInfo.toCompressedJSON(prop.property, classesMap),
            // eslint-disable-next-line deprecation/deprecation
            relatedClassPath: prop.relatedClassPath.map((classInfo) => EC_1.RelatedClassInfo.toCompressedJSON(classInfo, classesMap)),
        };
    }
    Property.toCompressedJSON = toCompressedJSON;
    /** Deserializes [[Property]] from JSON */
    function fromJSON(json) {
        return {
            property: EC_1.PropertyInfo.fromJSON(json.property),
            // eslint-disable-next-line deprecation/deprecation
            relatedClassPath: json.relatedClassPath.map((classInfo) => EC_1.RelatedClassInfo.fromJSON(classInfo)),
        };
    }
    Property.fromJSON = fromJSON;
})(Property = exports.Property || (exports.Property = {}));
//# sourceMappingURL=Property.js.map