"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hierarchies
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeKey = exports.StandardNodeTypes = void 0;
const EC_1 = require("../EC");
/**
 * Standard node types
 * @public
 */
var StandardNodeTypes;
(function (StandardNodeTypes) {
    StandardNodeTypes["ECInstancesNode"] = "ECInstancesNode";
    StandardNodeTypes["ECClassGroupingNode"] = "ECClassGroupingNode";
    StandardNodeTypes["ECPropertyGroupingNode"] = "ECPropertyGroupingNode";
    StandardNodeTypes["DisplayLabelGroupingNode"] = "DisplayLabelGroupingNode";
})(StandardNodeTypes = exports.StandardNodeTypes || (exports.StandardNodeTypes = {}));
/** @public */
var NodeKey;
(function (NodeKey) {
    /** Serialize given [[NodeKey]] to JSON */
    function toJSON(key) {
        if (isInstancesNodeKey(key))
            return Object.assign(Object.assign({}, key), { instanceKeys: key.instanceKeys.map(EC_1.InstanceKey.toJSON) });
        return Object.assign({}, key);
    }
    NodeKey.toJSON = toJSON;
    /** Deserialize node key from JSON */
    function fromJSON(json) {
        if (isInstancesNodeKey(json))
            return Object.assign(Object.assign({}, json), { instanceKeys: json.instanceKeys.map(EC_1.InstanceKey.fromJSON) });
        return Object.assign({}, json);
    }
    NodeKey.fromJSON = fromJSON;
    /** Checks if the supplied key is an [[ECInstancesNodeKey]] */
    function isInstancesNodeKey(key) {
        return key.type === StandardNodeTypes.ECInstancesNode;
    }
    NodeKey.isInstancesNodeKey = isInstancesNodeKey;
    /** Checks if the supplied key is an [[ECClassGroupingNodeKey]] */
    function isClassGroupingNodeKey(key) {
        return key.type === StandardNodeTypes.ECClassGroupingNode;
    }
    NodeKey.isClassGroupingNodeKey = isClassGroupingNodeKey;
    /** Checks if the supplied key is an [[ECPropertyGroupingNodeKey]] */
    function isPropertyGroupingNodeKey(key) {
        return key.type === StandardNodeTypes.ECPropertyGroupingNode;
    }
    NodeKey.isPropertyGroupingNodeKey = isPropertyGroupingNodeKey;
    /** Checks if the supplied key is a [[LabelGroupingNodeKey]] */
    function isLabelGroupingNodeKey(key) {
        return key.type === StandardNodeTypes.DisplayLabelGroupingNode;
    }
    NodeKey.isLabelGroupingNodeKey = isLabelGroupingNodeKey;
    /** Checks if the supplied key is a grouping node key */
    function isGroupingNodeKey(key) {
        return isClassGroupingNodeKey(key) || isPropertyGroupingNodeKey(key) || isLabelGroupingNodeKey(key);
    }
    NodeKey.isGroupingNodeKey = isGroupingNodeKey;
})(NodeKey = exports.NodeKey || (exports.NodeKey = {}));
//# sourceMappingURL=Key.js.map