"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hierarchies
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Node = void 0;
const LabelDefinition_1 = require("../LabelDefinition");
const Key_1 = require("./Key");
/** @public */
var Node;
(function (Node) {
    /** Serialize given [[Node]] to JSON */
    function toJSON(node) {
        const { key, label } = node, baseNode = __rest(node, ["key", "label"]);
        return Object.assign(Object.assign({}, baseNode), { key: Key_1.NodeKey.toJSON(key), labelDefinition: LabelDefinition_1.LabelDefinition.toJSON(label) });
    }
    Node.toJSON = toJSON;
    /** @internal */
    function toPartialJSON(node) {
        if (node.key === undefined) {
            return node;
        }
        const { key, label } = node, baseNode = __rest(node, ["key", "label"]);
        return Object.assign(Object.assign({}, baseNode), { key: Key_1.NodeKey.toJSON(key), labelDefinition: LabelDefinition_1.LabelDefinition.toJSON(label) });
    }
    Node.toPartialJSON = toPartialJSON;
    /** Deserialize [[Node]] from JSON */
    function fromJSON(json) {
        if (typeof json === "string")
            return JSON.parse(json, reviver);
        const { labelDefinition } = json, baseJson = __rest(json, ["labelDefinition"]);
        return Object.assign(Object.assign({}, baseJson), { key: Key_1.NodeKey.fromJSON(json.key), label: LabelDefinition_1.LabelDefinition.fromJSON(labelDefinition) });
    }
    Node.fromJSON = fromJSON;
    /** @internal */
    function fromPartialJSON(json) {
        if (json.key === undefined) {
            return json;
        }
        const { key, labelDefinition } = json, baseJson = __rest(json, ["key", "labelDefinition"]);
        return Object.assign(Object.assign({}, baseJson), { key: Key_1.NodeKey.fromJSON(key), label: LabelDefinition_1.LabelDefinition.fromJSON(labelDefinition) });
    }
    Node.fromPartialJSON = fromPartialJSON;
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing [[Node]] objects.
     *
     * @internal
     */
    function reviver(key, value) {
        return key === "" ? fromJSON(value) : value;
    }
    Node.reviver = reviver;
    /**
     * Deserialize nodes list from JSON
     * @param json JSON or JSON serialized to string to deserialize from
     * @returns Deserialized nodes list
     *
     * @internal
     */
    function listFromJSON(json) {
        if (typeof json === "string")
            return JSON.parse(json, listReviver);
        return json.map((m) => fromJSON(m));
    }
    Node.listFromJSON = listFromJSON;
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing [[Node]][] objects.
     *
     * @internal
     */
    function listReviver(key, value) {
        return key === "" ? listFromJSON(value) : value;
    }
    Node.listReviver = listReviver;
})(Node = exports.Node || (exports.Node = {}));
//# sourceMappingURL=Node.js.map