"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Hierarchies
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodePathFilteringData = exports.NodePathElement = void 0;
const Node_1 = require("./Node");
/** @public */
var NodePathElement;
(function (NodePathElement) {
    /** Serialize given [[NodePathElement]] to JSON */
    function toJSON(npe) {
        const result = {
            node: Node_1.Node.toJSON(npe.node),
            index: npe.index,
            children: npe.children.map(NodePathElement.toJSON),
        };
        if (undefined !== npe.isMarked)
            result.isMarked = npe.isMarked;
        if (undefined !== npe.filteringData)
            result.filteringData = NodePathFilteringData.toJSON(npe.filteringData);
        return result;
    }
    NodePathElement.toJSON = toJSON;
    /** Deserialize [[NodePathElement]] from JSON */
    function fromJSON(json) {
        if (typeof json === "string")
            return JSON.parse(json, reviver);
        const result = {
            index: json.index,
            node: Node_1.Node.fromJSON(json.node),
            children: listFromJSON(json.children),
        };
        if (undefined !== json.isMarked)
            result.isMarked = json.isMarked;
        if (undefined !== json.filteringData)
            result.filteringData = NodePathFilteringData.fromJSON(json.filteringData);
        return result;
    }
    NodePathElement.fromJSON = fromJSON;
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing [[NodePathElement]] objects.
     *
     * @internal
     */
    function reviver(key, value) {
        return key === "" ? fromJSON(value) : value;
    }
    NodePathElement.reviver = reviver;
    /**
     * Deserialize [[NodePathElement]] list from JSON
     * @param json JSON or JSON serialized to string to deserialize from
     * @returns Deserialized [[NodePathElement]] list
     *
     * @internal
     */
    function listFromJSON(json) {
        if (typeof json === "string")
            return JSON.parse(json, listReviver);
        return json.map((m) => fromJSON(m));
    }
    NodePathElement.listFromJSON = listFromJSON;
    /**
     * Reviver function that can be used as a second argument for
     * `JSON.parse` method when parsing [[NodePathElement]][] objects.
     *
     * @internal
     */
    function listReviver(key, value) {
        return key === "" ? listFromJSON(value) : value;
    }
    NodePathElement.listReviver = listReviver;
})(NodePathElement = exports.NodePathElement || (exports.NodePathElement = {}));
/** @public */
var NodePathFilteringData;
(function (NodePathFilteringData) {
    /** Serialize given [[NodePathFilteringData]] to JSON */
    function toJSON(npfd) {
        return {
            occurances: npfd.matchesCount,
            childrenOccurances: npfd.childMatchesCount,
        };
    }
    NodePathFilteringData.toJSON = toJSON;
    /** Deserialize [[NodePathFilteringData]] from JSON */
    function fromJSON(json) {
        return {
            matchesCount: json.occurances,
            childMatchesCount: json.childrenOccurances,
        };
    }
    NodePathFilteringData.fromJSON = fromJSON;
})(NodePathFilteringData = exports.NodePathFilteringData || (exports.NodePathFilteringData = {}));
//# sourceMappingURL=NodePathElement.js.map