"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module PresentationRules
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.RelatedPropertiesSpecialValues = exports.RelationshipMeaning = void 0;
/**
 * Meaning of the relationship
 * @public
 */
var RelationshipMeaning;
(function (RelationshipMeaning) {
    /**
     * Related instance is part of the primary instance. Related properties
     * with this meaning are displayed in UI as if they belonged to the
     * primary instance.
     */
    RelationshipMeaning["SameInstance"] = "SameInstance";
    /**
     * Related instance if not part of the primary instance - it should
     * appear as related. UI components may display related instance properties
     * differently, e.g. put them under a different category, etc.
     */
    RelationshipMeaning["RelatedInstance"] = "RelatedInstance";
})(RelationshipMeaning = exports.RelationshipMeaning || (exports.RelationshipMeaning = {}));
/**
 * Special values that can be used in [[RelatedPropertiesSpecification.propertyNames]]
 * @public
 */
var RelatedPropertiesSpecialValues;
(function (RelatedPropertiesSpecialValues) {
    /**
     * Used to specify that no properties should be included. Usually
     * used together with [[RelatedPropertiesSpecification.nestedRelatedProperties]]
     */
    RelatedPropertiesSpecialValues["None"] = "_none_";
    /**
     * Used to specify that all properties should be included.
     */
    RelatedPropertiesSpecialValues["All"] = "*";
})(RelatedPropertiesSpecialValues = exports.RelatedPropertiesSpecialValues || (exports.RelatedPropertiesSpecialValues = {}));
//# sourceMappingURL=RelatedPropertiesSpecification.js.map